//@line 4 "/builds/slave/tb-rel-c-esr38-l64_rpk_5-00000/l10n/hsb/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-esr38-l64_rpk_5-00000/l10n/hsb/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-esr38-l64_rpk_5-00000/l10n/hsb/calendar/lightning-l10n.js"
pref("calendar.week.start", 1);

//@line 12 "/builds/slave/tb-rel-c-esr38-l64_rpk_5-00000/l10n/hsb/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "hsb");

//@line 23 "/builds/slave/tb-rel-c-esr38-l64_rpk_5-00000/l10n/hsb/calendar/lightning-l10n.js"
pref("calendar.categories.names", "Dary,Dodawarjo,Dowol,Fawority,Ideje,Klienća,Kupc,Narodniny,Problemy,Projekty,Prózdniny,Pućowanje,Róčnica,Slědowanje,Status,Swjedźeń,Telefonaty,Wobchod,Wosobinske,Wšelčizny,Wubědźowanje,Zetkanje");
